﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Collections.ObjectModel;

using MindFusion.Charting;
using MindFusion.Charting.Components;
using MindFusion.Drawing;

using Color = System.Drawing.Color;


namespace BubbleChart
{
	public partial class MainForm : Form
	{
		public MainForm()
		{
			InitializeComponent();

			// create sample data
			bubbleChart.Series = GetSeriesCollection();		

			// axis titles and ranges
			bubbleChart.XAxis.Title = "Average relative annual growth (%)";
			bubbleChart.XAxis.MinValue = -1;
			bubbleChart.XAxis.MaxValue = 1;
			bubbleChart.YAxis.Title = "July 1, 2015 projection";
			bubbleChart.YAxis.MinValue = 0;
			bubbleChart.YAxis.MaxValue = 100;

			// background appearance
			bubbleChart.ShowZoomWidgets = true;
			bubbleChart.GridType = GridType.Vertical;
			bubbleChart.BackColor = Color.FromArgb(45, 57, 86);
			bubbleChart.Theme.GridColor1 = Color.FromArgb(100, 0, 52, 102);
			bubbleChart.Theme.GridColor2 = Color.FromArgb(200, 0, 52, 102);
			bubbleChart.Theme.LegendBackground = new SolidBrush(Color.FromArgb(0, 52, 102));

			// series colors
			bubbleChart.Theme.CommonSeriesFills = new List<Brush>
			{
				new LinearGradientBrush(Color.Transparent, Color.FromArgb(156, 170, 198)),
				new LinearGradientBrush(Color.Transparent, Color.FromArgb(206, 0, 0))
			};
			bubbleChart.Theme.UniformSeriesStroke = bubbleChart.Theme.HighlightStroke =
				bubbleChart.Theme.DataLabelsBrush = bubbleChart.Theme.LegendTitleBrush =
				bubbleChart.Theme.LegendBorderStroke = bubbleChart.Theme.AxisLabelsBrush =
				bubbleChart.Theme.AxisTitleBrush = bubbleChart.Theme.AxisStroke = new SolidBrush(Color.White);

			bubbleChart.Theme.HighlightStrokeDashStyle = System.Drawing.Drawing2D.DashStyle.Dot;

			SetupControls();
		}

		private void SetupControls()
		{
			cbGridType.SelectedIndex = (int)bubbleChart.GridType;
			cbPinGrid.Checked = bubbleChart.PinGrid;
			cbShowScatter.Checked = bubbleChart.ShowScatter;
			cbShowX.Checked = bubbleChart.ShowXCoordinates;
			cbShowY.Checked = bubbleChart.ShowYCoordinates;
			cbShowXTicks.Checked = bubbleChart.ShowXTicks;
			cbShowYTicks.Checked = bubbleChart.ShowYTicks;
			cbAllowPan.Checked = bubbleChart.AllowPan;
			cbMoveLegend.Checked = bubbleChart.AllowMoveLegend;
			cbHorAlign.SelectedIndex = (int)bubbleChart.LegendHorizontalAlignment;
			cbVertAlign.SelectedIndex = (int)bubbleChart.LegendVerticalAlignment;
			tbMarginLeft.Minimum = 0;
			tbMarginLeft.Maximum = bubbleChart.Width - 100;
			tbMarginLeft.Value = (int)bubbleChart.LegendMargin.Left;
			tbMarginTop.Minimum = 0;
			tbMarginTop.Maximum = bubbleChart.Height - 100;
			tbMarginTop.Value = (int)bubbleChart.LegendMargin.Top;
			cbShowLabels.Checked = true;
			cbLegend.Checked = true;
			cbWidgets.Checked = bubbleChart.ShowZoomWidgets;
		}

		private ObservableCollection<Series> GetSeriesCollection()
		{
			// bubble chart requires three dimensional data;
			// two dimensions for position and one for size
			var series3D1 = new PointSeries3D(
				new List<Point3D>
				{
					new Point3D(0.32f, 81, 9.5f * 10),
					new Point3D(0.39f, 66, 7.8f * 10),
					new Point3D(0.75f, 65, 7.6f * 10),
					new Point3D(0.49f, 60, 7.1f * 10)
				},
				new List<string> { "Germany", "France", "UK", "Italy" });
			series3D1.Title = ">50 000 000";

			var series3D2 = new PointSeries3D(
				new List<Point3D>
				{
					new Point3D(-0.28f, 46, 5.4f * 10),
					new Point3D(-0.32f, 42, 5 * 10),
					new Point3D(0.05f, 38, 4.5f * 10),
					new Point3D(-0.4f, 19, 2.3f * 10)
				},
				new List<string> { "Spain", "Ukraine", "Poland", "Romania" });
			series3D2.Title = "<50 000 000";

			var data = new ObservableCollection<Series>();
			data.Add(series3D1);
			data.Add(series3D2);

			return data;
		}

		private void cbGridType_SelectedIndexChanged(object sender, EventArgs e)
		{
			bubbleChart.GridType = (GridType)cbGridType.SelectedIndex;
		}

		private void cbPinGrid_CheckedChanged(object sender, EventArgs e)
		{
			bubbleChart.PinGrid = cbPinGrid.Checked;
		}

		private void cbShowScatter_CheckedChanged(object sender, EventArgs e)
		{
			bubbleChart.ShowScatter = cbShowScatter.Checked;
		}

		private void cbShowX_CheckedChanged(object sender, EventArgs e)
		{
			bubbleChart.ShowXCoordinates = cbShowX.Checked;
		}

		private void cbShowY_CheckedChanged(object sender, EventArgs e)
		{
			bubbleChart.ShowYCoordinates = cbShowY.Checked;
		}

		private void cbShowXTicks_CheckedChanged(object sender, EventArgs e)
		{
			bubbleChart.ShowXTicks = cbShowXTicks.Checked;
		}

		private void cbShowYTicks_CheckedChanged(object sender, EventArgs e)
		{
			bubbleChart.ShowYTicks = cbShowYTicks.Checked;
		}

		private void cbAllowPan_CheckedChanged(object sender, EventArgs e)
		{
			bubbleChart.AllowPan = cbAllowPan.Checked;
		}

		private void cbMoveLegend_CheckedChanged(object sender, EventArgs e)
		{
			bubbleChart.AllowMoveLegend = cbMoveLegend.Checked;
		}

		private void cbHorAlign_SelectedIndexChanged(object sender, EventArgs e)
		{
			bubbleChart.LegendHorizontalAlignment = (LayoutAlignment)cbHorAlign.SelectedIndex;
		}

		private void cbVertAlign_SelectedIndexChanged(object sender, EventArgs e)
		{
			bubbleChart.LegendVerticalAlignment = (LayoutAlignment)cbVertAlign.SelectedIndex;
		}

		private void tbMarginLeft_Scroll(object sender, EventArgs e)
		{
			bubbleChart.LegendMargin = new Margins(tbMarginLeft.Value, bubbleChart.LegendMargin.Top, 0, 0);
		}

		private void tbMarginTop_Scroll(object sender, EventArgs e)
		{
			bubbleChart.LegendMargin = new Margins(bubbleChart.LegendMargin.Left, tbMarginTop.Value, 0, 0);
		}

		private void cbShowLabels_CheckedChanged(object sender, EventArgs e)
		{
			if (cbShowLabels.Checked)
				bubbleChart.ShowDataLabels |= LabelKinds.InnerLabel;
			else
				bubbleChart.ShowDataLabels ^= LabelKinds.InnerLabel;
			bubbleChart.Invalidate();
		}

		private void cbLegend_CheckedChanged(object sender, EventArgs e)
		{
			bubbleChart.ShowLegend = cbLegend.Checked;
		}

		private void cbWidgets_CheckedChanged(object sender, EventArgs e)
		{
			bubbleChart.ShowZoomWidgets = cbWidgets.Checked;
		}
	}
}